==> cenplot-0.0.1.tar.gz: cenplot-0.0.1/cenplot/lib/track/settings.py <==
from dataclasses import dataclass
from typing import Literal


@dataclass
class DefaultPlotSettings:
    """
    Default plot options settings.
    """

    fontsize: float | str = "medium"
    """
    Font size for track text.
    """

    title_fontsize: float | str = "large"
    """
    Font size for track title.
    """

    legend: bool = True
    """
    Show the legend.
    """

    legend_ncols: int | None = None
    """
    Number of columns for legend entries.
    """

    legend_fontsize: str = "medium"
    """
    Legend font size.
    """

    legend_title: str | None = None
    """
    Set legend title.
    * ex. "HOR monomers for {chrom}"
    """

    legend_title_fontsize: str = "large"
    """
    Legend title font size.
    """

    legend_title_only: bool = False
    """
    Hide all legend elements except titile.
    """

    hide_x: bool = True
    """
    Hide the x-axis ticks, ticklabels, and spines.
    """


@dataclass
class SelfIdentPlotSettings(DefaultPlotSettings):
    """
    Self-identity heatmap triangle plot options.
    """

    invert: bool = True
    """
    Invert the self identity triangle.
    """
    legend_bins: int = 300
    """
    Number of bins for `perc_identity_by_events` in the legend.
    """
    legend_xmin: float = 70.0
    """
    Legend x-min coordinate. Used to constrain x-axis limits.
    """
    legend_asp_ratio: float | None = 1.0
    """
    Aspect ratio of legend. If `None`, takes up entire axis.
    """


@dataclass
class LabelPlotSettings(DefaultPlotSettings):
    """
    Label plot options.
    """

    DEF_COLOR = "black"
    """
    Default color for label.
    """

    color: str | None = None
    """
    Label color. Used if no color is provided in `item_rgb` column.
    """

    use_item_rgb: bool = True
    """
    Use `item_rgb` column if provided. Otherwise, generate a random color for each value in column `name`.
    """

    alpha: float = 1.0
    """
    Label alpha.
    """

    border: bool = False
    """
    Add black border containing all added labels.
    """


@dataclass
class BarPlotSettings(DefaultPlotSettings):
    """
    Bar plot options.
    """

    DEF_COLOR = "black"
    """
    Default color for bar plot.
    """

    color: str | None = None
    """
    Color of bars. If `None`, uses `item_rgb` column colors.
    """

    alpha: float = 1.0
    """
    Alpha of bars.
    """

    ymin: int = 0
    """
    Minimum y-value.
    """

    ymax: int | None = None
    """
    Maximum y-value.
    """

    label: str | None = None
    """
    Label to add to legend.
    """


@dataclass
class HOROrtPlotSettings(DefaultPlotSettings):
    """
    Higher order repeat orientation arrow plot options.
    """

    DEF_COLOR = "black"
    """
    Default color for arrows.
    """
    scale: float = 50
    """
    Scale arrow attributes by this factor as well as length.
    """
    fwd_color: str | None = None
    """
    Color of `+` arrows.
    """
    rev_color: str | None = None
    """
    Color of `-` arrows.
    """
    live_only: bool = True
    """
    Only plot live HORs.
    """
    mer_filter: int = 2
    """
    Filter HORs that have at least 2 monomers.
    """


@dataclass
class HORPlotSettings(DefaultPlotSettings):
    """
    Higher order repeat plot options.
    """

    sort_order: Literal["ascending", "descending"] = "descending"
    """
    Plot HORs by `{mode}` in `{sort_order}` order.

    Mode:
    * If `{mer}`, sort by `mer` number
    * If `{hor}`, sort by `hor` frequency.
    """
    mode: Literal["mer", "hor"] = "mer"
    """
    Plot HORs with `mer` or `hor`.
    """
    live_only: bool = True
    """
    Only plot live HORs.
    """
    mer_filter: int = 2
    """
    Filter HORs that have at least 2 monomers.
    """
    hor_filter: int = 5
    """
    Filter HORs that have occur fewer than hor_filter times.
    """
    use_item_rgb: bool = False
    """
    Use `item_rgb` column for color.
    """
    split_prop: bool = False
    """
    If split, divide proportion evenly across each split track.
    """
    border: bool = False
    """
    Add black border containing all added labels.
    """


@dataclass
class LegendPlotSettings(DefaultPlotSettings):
    index: int | None = None
    """
    Index of plot to get legend of.
    """


@dataclass
class PositionPlotSettings(DefaultPlotSettings):
    pass


@dataclass
class SpacerPlotSettings(DefaultPlotSettings):
    pass


PlotSettings = (
    HORPlotSettings
    | HOROrtPlotSettings
    | SelfIdentPlotSettings
    | BarPlotSettings
    | LabelPlotSettings
    | LegendPlotSettings
    | PositionPlotSettings
    | SpacerPlotSettings
)
"""
Type annotation for all possible settings for the various plot types.
"""

==> cenplot-0.0.2.tar.gz: cenplot-0.0.2/cenplot/lib/track/settings.py <==
from dataclasses import dataclass
from typing import Literal


@dataclass
class DefaultTrackSettings:
    """
    Default plot options settings.
    """

    fontsize: float | str = "medium"
    """
    Font size for track text.
    """

    title_fontsize: float | str = "large"
    """
    Font size for track title.
    """

    legend: bool = True
    """
    Show the legend.
    """

    legend_ncols: int | None = None
    """
    Number of columns for legend entries.
    """

    legend_fontsize: str = "medium"
    """
    Legend font size.
    """

    legend_title: str | None = None
    """
    Set legend title.
    * ex. "HOR monomers for {chrom}"
    """

    legend_title_fontsize: str = "large"
    """
    Legend title font size.
    """

    legend_title_only: bool = False
    """
    Hide all legend elements except titile.
    """

    hide_x: bool = True
    """
    Hide the x-axis ticks, ticklabels, and spines.
    """


@dataclass
class SelfIdentTrackSettings(DefaultTrackSettings):
    """
    Self-identity heatmap triangle plot options.
    """

    invert: bool = True
    """
    Invert the self identity triangle.
    """
    legend_bins: int = 300
    """
    Number of bins for `perc_identity_by_events` in the legend.
    """
    legend_xmin: float = 70.0
    """
    Legend x-min coordinate. Used to constrain x-axis limits.
    """
    legend_asp_ratio: float | None = 1.0
    """
    Aspect ratio of legend. If `None`, takes up entire axis.
    """


@dataclass
class LabelTrackSettings(DefaultTrackSettings):
    """
    Label plot options.
    """

    DEF_COLOR = "black"
    """
    Default color for label.
    """

    color: str | None = None
    """
    Label color. Used if no color is provided in `item_rgb` column.
    """

    use_item_rgb: bool = True
    """
    Use `item_rgb` column if provided. Otherwise, generate a random color for each value in column `name`.
    """

    alpha: float = 1.0
    """
    Label alpha.
    """

    border: bool = False
    """
    Add black border containing all added labels.
    """


@dataclass
class BarTrackSettings(DefaultTrackSettings):
    """
    Bar plot options.
    """

    DEF_COLOR = "black"
    """
    Default color for bar plot.
    """

    color: str | None = None
    """
    Color of bars. If `None`, uses `item_rgb` column colors.
    """

    alpha: float = 1.0
    """
    Alpha of bars.
    """

    ymin: int = 0
    """
    Minimum y-value.
    """

    ymax: int | None = None
    """
    Maximum y-value.
    """

    label: str | None = None
    """
    Label to add to legend.
    """


@dataclass
class HOROrtTrackSettings(DefaultTrackSettings):
    """
    Higher order repeat orientation arrow plot options.
    """

    DEF_COLOR = "black"
    """
    Default color for arrows.
    """
    scale: float = 50
    """
    Scale arrow attributes by this factor as well as length.
    """
    fwd_color: str | None = None
    """
    Color of `+` arrows.
    """
    rev_color: str | None = None
    """
    Color of `-` arrows.
    """
    live_only: bool = True
    """
    Only plot live HORs.
    """
    mer_filter: int = 2
    """
    Filter HORs that have at least 2 monomers.
    """


@dataclass
class HORTrackSettings(DefaultTrackSettings):
    """
    Higher order repeat plot options.
    """

    sort_order: Literal["ascending", "descending"] = "descending"
    """
    Plot HORs by `{mode}` in `{sort_order}` order.

    Mode:
    * If `{mer}`, sort by `mer` number
    * If `{hor}`, sort by `hor` frequency.
    """
    mode: Literal["mer", "hor"] = "mer"
    """
    Plot HORs with `mer` or `hor`.
    """
    live_only: bool = True
    """
    Only plot live HORs.
    """
    mer_filter: int = 2
    """
    Filter HORs that have at least 2 monomers.
    """
    hor_filter: int = 5
    """
    Filter HORs that have occur fewer than hor_filter times.
    """
    use_item_rgb: bool = False
    """
    Use `item_rgb` column for color.
    """
    split_prop: bool = False
    """
    If split, divide proportion evenly across each split track.
    """
    border: bool = False
    """
    Add black border containing all added labels.
    """


@dataclass
class LegendTrackSettings(DefaultTrackSettings):
    index: int | None = None
    """
    Index of plot to get legend of.
    """


@dataclass
class PositionTrackSettings(DefaultTrackSettings):
    pass


@dataclass
class SpacerTrackSettings(DefaultTrackSettings):
    pass


TrackSettings = (
    HORTrackSettings
    | HOROrtTrackSettings
    | SelfIdentTrackSettings
    | BarTrackSettings
    | LabelTrackSettings
    | LegendTrackSettings
    | PositionTrackSettings
    | SpacerTrackSettings
)
"""
Type annotation for all possible settings for the various plot types.
"""
